"""Implementations of 'EnumWithSelectedValue' in Python.

As Python does not have an implicit operator, this is the next
best solution for implementing these types properly.
"""

from __future__ import annotations

from enum import Enum
from typing import List, TypeVar

from mastapy.bearings.bearing_designs.rolling import _2154
from mastapy._internal import mixins
from mastapy._internal.python_net import python_net_import

_ARRAY = python_net_import("System", "Array")
_ENUM_WITH_SELECTED_VALUE = python_net_import(
    "SMT.MastaAPI.Utility.Property", "EnumWithSelectedValue"
)


__docformat__ = "restructuredtext en"
__all__ = ("EnumWithSelectedValue_FatigueLoadLimitCalculationMethodEnum",)


Self = TypeVar(
    "Self", bound="EnumWithSelectedValue_FatigueLoadLimitCalculationMethodEnum"
)


class EnumWithSelectedValue_FatigueLoadLimitCalculationMethodEnum(
    mixins.EnumWithSelectedValueMixin, Enum
):
    """EnumWithSelectedValue_FatigueLoadLimitCalculationMethodEnum

    A specific implementation of 'EnumWithSelectedValue' for 'FatigueLoadLimitCalculationMethodEnum' types.
    """

    __qualname__ = "FatigueLoadLimitCalculationMethodEnum"

    @classmethod
    def wrapper_type(cls) -> "_ENUM_WITH_SELECTED_VALUE":
        """Pythonnet type of this class.

        Note:
            This property is readonly.
        """

        return _ENUM_WITH_SELECTED_VALUE

    @classmethod
    def wrapped_type(cls) -> "_2154.FatigueLoadLimitCalculationMethodEnum":
        """Wrapped Pythonnet type of this class.

        Note:
            This property is readonly
        """

        return _2154.FatigueLoadLimitCalculationMethodEnum

    @classmethod
    def implicit_type(cls) -> "_2154.FatigueLoadLimitCalculationMethodEnum.type_()":
        """Implicit Pythonnet type of this class.

        Note:
            This property is readonly.
        """

        return _2154.FatigueLoadLimitCalculationMethodEnum.type_()

    @property
    def selected_value(self: Self) -> "_2154.FatigueLoadLimitCalculationMethodEnum":
        """mastapy.bearings.bearing_designs.rolling.FatigueLoadLimitCalculationMethodEnum

        Note:
            This property is readonly.
        """
        return None

    @property
    def available_values(
        self: Self,
    ) -> "List[_2154.FatigueLoadLimitCalculationMethodEnum]":
        """List[mastapy.bearings.bearing_designs.rolling.FatigueLoadLimitCalculationMethodEnum]

        Note:
            This property is readonly.
        """
        return None
